# Generated by Django 3.2.15 on 2022-09-08 17:06

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='HelpTextString',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('model_label', models.CharField(editable=False, max_length=255)),
                ('identifier', models.CharField(editable=False, max_length=255)),
                ('text', models.TextField(blank=True)),
            ],
            options={
                'ordering': ('model_label', 'identifier'),
            },
        ),
        migrations.AddIndex(
            model_name='helptextstring',
            index=models.Index(fields=['model_label', 'identifier'], name='help_text_identifier_idx'),
        ),
        migrations.AddConstraint(
            model_name='helptextstring',
            constraint=models.UniqueConstraint(fields=('model_label', 'identifier'), name='unique_help_text_identifier'),
        ),
    ]
